/**********************************************************************************/
/*    Demo program for:								  */
/*	  Board: LPC-P1114              					  */
/*    Manufacture: OLIMEX                                                   	  */
/*	  COPYRIGHT (C) 2011							  */
/*    Designed by: Engineer Penko T. Bozhkov                                      */
/*    Module Name    :  main module                                               */
/*    File   Name    :  main.c                                                    */
/*    Revision       :  Rev.A                                                     */
/*      -> Built with IAR's versions written below                                */
/*    Date           :  11.07.2011                                                */
/*    Built with IAR Embedded Workbench Version: 6.20.1                           */
/**********************************************************************************/
#include  <nxp/iolpc1114.h>
#include  <intrinsics.h>

// Functions Prototypes:
void Delay(volatile unsigned long cycles);
void init_devices(void);
void main(void);

// Definitions:
#define LED0_ON   GPIO3DATA &= ~0x00000001;  
#define LED0_OFF  GPIO3DATA |= 0x00000001;


/**********************************************************************************/
/*  Function name: Delay                                                          */
/*  	Parameters                                                                */
/*          Input   :  cycles                                                     */
/*          Output  :  No	                                                  */
/*	Action: Simple delay							  */
/**********************************************************************************/
void Delay(volatile unsigned long cycles){
  while(cycles){cycles--;}
}


/**********************************************************************************/
/*  Function name: init_devices	                                                  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Initialize all used LPC1114 peripheral devices. 	  	  */
/**********************************************************************************/
void init_devices(void){
  // 1. Disable interrupts during initialization process
  __disable_interrupt();
  
  // 2.Select System Clock
  // By default settings are this:
  // main system clock -> from internal RC oscillator(IRC) 12MHz/1% accuracy, no dividers
  SYSAHBCLKCTRL_bit.GPIO = 1;
  SYSAHBCLKCTRL_bit.IOCON = 1;
  
  // 3.Ports initialization
  IOCON_PIO3_0 = 0xC0; // Function PIO3_0; Disable pull-up/down; Disable Hysteresis
  GPIO3DIR = 0x01;     // GPIO data direction register: 1 -> Outpt, 0 -> Input
  GPIO3DATA = 0x01;    // PIO3_0 in state "1" if output
 
  // 4.Peripherals initialization 
  // Not requred here
  
  // 5.Enable interrupts. Do this at the END of the initialization!!!!!!!!
  __enable_interrupt();
}

/**********************************************************************************/
/*  Function name: main	                                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Manage all reqested tasks.                    	  		  */
/**********************************************************************************/
void main(void){
  init_devices();
  while(1){
    LED0_ON;
    Delay(500000);
    LED0_OFF;
    Delay(500000);
  }
}


